==> GOUD-1.0.2.tar.gz: GOUD-1.0.2/README.md <==
# GOUD

Introducción a Goud

Goud es una librería de Python que proporciona algoritmos de optimización para la ingeniería industrial. La librería está diseñada para ser fácil de usar y comprender, y está completamente comentada en español.

Problema

Actualmente, no existe una librería en Python que proporcione una gama completa de algoritmos de optimización para la ingeniería industrial. Las pocas librerías que existen están dispersas en muchos módulos, lo que dificulta su uso.

Solución

Goud ofrece una solución a este problema al proporcionar una única librería que contiene una amplia gama de algoritmos de optimización para la ingeniería industrial. La librería está dividida en tres módulos principales:

Pronósticos: Este módulo proporciona algoritmos de pronóstico para predecir la demanda de productos o servicios.
Programación agregada: Este módulo proporciona algoritmos para determinar la producción y la fuerza de trabajo de una empresa a largo plazo.
Programación de la producción: Este módulo proporciona algoritmos para determinar la secuencia de producción de una empresa.
Características

Goud cuenta con las siguientes características:

Una amplia gama de algoritmos de optimización para la ingeniería industrial.
Una interfaz fácil de usar y comprender.
Código completamente comentado en español.
Instalación

Goud está disponible en GitHub y se puede instalar con pip.

Esta estara dividia por modulos de:

GOUD
1.1. Pronósticos
1.1.1. Regresión Lineal
1.1.2. Promedio Móvil
1.1.3. Promedio Móvil Ponderado
1.1.4. Suavización Exponencial Simple
1.1.5. Suavización Exponencial Doble (HOLT)
1.1.6. Suavización Exponencial Triple (HOLT-WINTERS)
1.2. Planeacion Agregada
1.2.1. Planeación Agregada Con Inventario Cero
1.2.2. Planeacion Agregada Con Fuerza De Trabajo Constante
1.2.3. Planeacion Agregada Con Fuerza De Trabajo Variable
1.2.4. Planeacion Agregada De Trabajo Mixto (Programación Lineal)
1.3. Progrmaación De La Producción (MPS) 
1.3.1. Balanceo De Línea
1.3.1. Reglas de secuenciación
1.3.1.1. SPT: Tiempo de Procesamiento más Corto
1.3.1.2. LPT: Tiempo de Procesamiento más Largo
1.3.1.3. EFT: Tiempo de Finalización más Temprano
1.3.1.4. LFT: Tiempo de Finalización más Tardío
1.3.1.5. EDD: Tiempo de Entrega (Earliest Due Date)
1.3.1.6. S/EDD: Relación Tiempo de Procesamiento-Tiempo de Entrega (Corto/Earliest Due Date)
1.3.1.7. L/EDD: Relación Tiempo de Procesamiento-Tiempo de Entrega (Largo/Earliest Due Date)
1.3.1.8. HLC: Costo de Retraso más Alto
1.3.3. Secuenciación De Trabajos
1.3.3.1. Jhonson
1.3.3.2. Branch And Bound
1.3.3.3. CDS
1.3.3.4. Programación Lineal

Ejemplos

Aquí hay algunos ejemplos de cómo se puede usar Goud:

Un ingeniero industrial puede usar Goud para pronosticar la demanda de un nuevo producto.
Un gerente de producción puede usar Goud para determinar la cantidad de productos que debe fabricar una empresa para cumplir con la demanda.
Un gerente de operaciones puede usar Goud para determinar la secuencia de producción de una línea de ensamblaje.
Conclusión

Goud es una herramienta útil para los ingenieros industriales que necesitan implementar algoritmos de optimización en sus proyectos. La librería es fácil de usar y comprender, y está disponible en español.

==> GOUD-1.0.5.tar.gz: GOUD-1.0.5/README.md <==
# GOUD

Introducción a Goud

Goud es una librería de Python que proporciona algoritmos de optimización para la ingeniería industrial. La librería está diseñada para ser fácil de usar y comprender, y está completamente comentada en español.

Problema

Actualmente, no existe una librería en Python que proporcione una gama completa de algoritmos de optimización para la ingeniería industrial. Las pocas librerías que existen están dispersas en muchos módulos, lo que dificulta su uso.

Solución

Goud ofrece una solución a este problema al proporcionar una única librería que contiene una amplia gama de algoritmos de optimización para la ingeniería industrial. La librería está dividida en tres módulos principales:

Pronósticos: Este módulo proporciona algoritmos de pronóstico para predecir la demanda de productos o servicios.
Programación agregada: Este módulo proporciona algoritmos para determinar la producción y la fuerza de trabajo de una empresa a largo plazo.
Programación de la producción: Este módulo proporciona algoritmos para determinar la secuencia de producción de una empresa.
Características

Goud cuenta con las siguientes características:

Una amplia gama de algoritmos de optimización para la ingeniería industrial.
Una interfaz fácil de usar y comprender.
Código completamente comentado en español.
Instalación

Goud está disponible en GitHub y se puede instalar con pip.

Esta estara dividia por modulos de:

GOUD
1. Pronósticos
1.1. Regresión Lineal
1.2. Promedio Móvil
1.3. Promedio Móvil Ponderado
1.4. Suavización Exponencial Simple
1.5. Suavización Exponencial Doble (HOLT)
1.6. Suavización Exponencial Triple (HOLT-WINTERS)
2. Planeación Agregada
2.1. Planeación Agregada Con Inventario Cero
2.2. Planeación Agregada Con Fuerza De Trabajo Constante
2.3. Planeación Agregada Con Sin tiempo Extra
2.4. Planeación Agregada Con Sin subcontratación
2.5. Planeación Agregada De Trabajo Mixto (Programación Lineal)
3. Programación De La Producción (MPS)
3.1. Balanceo De Línea
3.1. Reglas de secuenciación
3.1.1. SPT: Tiempo de Procesamiento más Corto
3.1.2. LPT: Tiempo de Procesamiento más Largo
3.1.3. EFT: Tiempo de Finalización más Temprano
3.1.4. LFT: Tiempo de Finalización más Tardío
3.1.5. EDD: Tiempo de Entrega (Earliest Due Date)
3.1.6. S/EDD: Relación Tiempo de Procesamiento-Tiempo de Entrega (Corto/Earliest Due Date)
3.1.7. L/EDD: Relación Tiempo de Procesamiento-Tiempo de Entrega (Largo/Earliest Due Date)
3.1.8. HLC: Costo de Retraso más Alto
3.3. Secuenciación De Trabajos
3.3.1. Jhonson
3.3.2. Branch And Bound
3.3.3. CDS
3.3.4. Programación Lineal

Ejemplos

Aquí hay algunos ejemplos de cómo se puede usar Goud:

Un ingeniero industrial puede usar Goud para pronosticar la demanda de un nuevo producto.
Un gerente de producción puede usar Goud para determinar la cantidad de productos que debe fabricar una empresa para cumplir con la demanda.
Un gerente de operaciones puede usar Goud para determinar la secuencia de producción de una línea de ensamblaje.
Conclusión

Goud es una herramienta útil para los ingenieros industriales que necesitan implementar algoritmos de optimización en sus proyectos. La librería es fácil de usar y comprender, y está disponible en español.
